==> haskell-cryptohash-0.11.9-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cryptohash/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash
version: 0.11.9
id: cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
key: crypt_GEQ1t4Tm0IqFmYz8P9KrIn
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-cryptohash
synopsis: collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.
    .
    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.
    .
    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
    .
    Simple examples using the unified API:
    .
    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
    .
    Simple examples using the module API:
    .
    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])
    .
    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224
category: Data, Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash Crypto.Hash.Types Crypto.MAC Crypto.Hash.SHA1
    Crypto.Hash.SHA224 Crypto.Hash.SHA256 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.SHA3
    Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.Skein256 Crypto.Hash.Skein512
    Crypto.Hash.Tiger Crypto.Hash.Whirlpool Crypto.MAC.HMAC
    Crypto.MAC.SHA3
hidden-modules: Crypto.Hash.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-0.11.9
hs-libraries: HScryptohash-0.11.9-GEQ1t4Tm0IqFmYz8P9KrIn
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    memory-0.11-3a745e41fe78387f608c420e9b455d25
haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html: /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-0.11.9-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cryptohash/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash
version: 0.11.9
id: cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
key: crypt_E50adij9XxwLSq9g8Uixjd
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-cryptohash
synopsis: collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.
    .
    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.
    .
    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
    .
    Simple examples using the unified API:
    .
    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
    .
    Simple examples using the module API:
    .
    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])
    .
    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224
category: Data, Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash Crypto.Hash.Types Crypto.MAC Crypto.Hash.SHA1
    Crypto.Hash.SHA224 Crypto.Hash.SHA256 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.SHA3
    Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.Skein256 Crypto.Hash.Skein512
    Crypto.Hash.Tiger Crypto.Hash.Whirlpool Crypto.MAC.HMAC
    Crypto.MAC.SHA3
hidden-modules: Crypto.Hash.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-0.11.9
hs-libraries: HScryptohash-0.11.9-E50adij9XxwLSq9g8Uixjd
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html: /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
